use crate::app_config::AppConfig;
use crate::extractors::auth_extractor::AuthExtractor;
use crate::extractors::local_auth_extractor::LocalAuthEnabled;
use actix_web::{web, HttpResponse, Responder};

#[derive(serde::Deserialize)]
pub struct LocalAuthReq {
    username: String,
    password: String,
}

/// Perform local authentication
pub async fn local_auth(
    local_auth_enabled: LocalAuthEnabled,
    req: web::Json<LocalAuthReq>,
    auth: AuthExtractor,
) -> impl Responder {
    if !*local_auth_enabled {
        log::error!("Local auth attempt while this authentication method is disabled!");
        return HttpResponse::UnprocessableEntity().json("Local authentication is disabled!");
    }

    if !AppConfig::get().check_local_login(&req.username, &req.password) {
        log::error!("Local auth attempt with invalid credentials!");
        return HttpResponse::Unauthorized().json("Invalid credentials!");
    }

    auth.authenticate(&req.username);

    HttpResponse::Accepted().json("Welcome")
}

#[derive(serde::Serialize)]
struct CurrentUser {
    id: String,
}

/// Get current authenticated user
pub async fn current_user(auth: AuthExtractor) -> impl Responder {
    HttpResponse::Ok().json(CurrentUser {
        id: auth.id().unwrap(),
    })
}
